@@ -164,7 +164,7 @@ class Mentor(Model):
     class Meta:
         auto_author = 'user'
         serializer_fields=["@id", "phone", "headline", "biography", "city", "skills", "linkedin",\
-                           "twitter", "organisation", "fields", "languages", "country"]
+                           "twitter", "organisation", "fields", "languages", "country", "organisationContact", "organisationName"]
         nested_fields=["user", "organisation", "fields", "languages", "country"]
         container_path = 'mentors/'
         rdf_type = 'coopstarter:mentor'
